/*
	Volcanic Island by Wolfenhex

	This map can be a tropical paradise or a frozen wasteland.  It
	consists of an island with a volcano surrounded by a forest.
	The volcano can only be entered by flying units and will erupt
	every 15 minutes covering the map in earthquakes and meteors.
	There are a lot of resources allowing the players to keep their
	armies big and the casualty rate when the volcano erupts high.
	A campfire has been provided for every player so they can have
	a luau or keep their units warm depending on which type of map
	is made.
*/

void main(void) {

	rmSetStatusText("",0.01);

	int myEnvironment = rmRandInt(1,2); // 1 = Frozen 2 = Tropical

	int j = 0;
	int k = 0;

	int myTiles = 15000;

	if(cMapSize == 1) {
		myTiles = 25000;
	}

	int mySize = 2 * sqrt(cNumberNonGaiaPlayers * myTiles);

	rmSetMapSize(mySize,mySize);

	rmSetSeaLevel(0);

	if(myEnvironment == 1) {
		rmSetSeaType("Norwegian Sea");
	}
	else {
		rmSetSeaType("Red Sea");
	}

	rmTerrainInitialize("water");

// Constraints

	rmSetStatusText("",0.04);

	int myAvoidEdgeConstraint       = rmCreateBoxConstraint("avoid edge constraint",rmXTilesToFraction(5),rmZTilesToFraction(5),1.0 - rmXTilesToFraction(5),1.0 - rmZTilesToFraction(5));
	int myAvoidFishConstraint       = rmCreateTypeDistanceConstraint("avoid fish constraint","fish",25.0);
	int myAvoidFoodConstraint       = rmCreateTypeDistanceConstraint("avoid food constraint","food",5.0);
	int myAvoidGoldConstraint       = rmCreateTypeDistanceConstraint("avoid gold constraint","gold",25.0);
	int myAvoidHerdableConstraint   = rmCreateTypeDistanceConstraint("avoid herdable constraint","herdable",25.0);
	int myAvoidHuntableConstraint   = rmCreateTypeDistanceConstraint("avoid huntable constraint","huntable",25.0);
	int myAvoidLandConstraint       = rmCreateTerrainDistanceConstraint("avoid land constraint","land",true,10.0);
	int myAvoidOrcaConstraint       = rmCreateTypeDistanceConstraint("avoid orca constraint","orca",25.0);
	int myAvoidRelicConstraint      = rmCreateTypeDistanceConstraint("avoid relic constraint","relic",25.0);
	int myAvoidSettlementConstraint = rmCreateTypeDistanceConstraint("avoid settlement constraint","AbstractSettlement",10.0);
	int myAvoidSharkConstraint      = rmCreateTypeDistanceConstraint("avoid shark constraint","shark",25.0);
	int myAvoidTreeConstraint       = rmCreateTypeDistanceConstraint("avoid tree constraint","tree",5.0);
	int myAvoidWhaleConstraint      = rmCreateTypeDistanceConstraint("avoid whale constraint","whale",25.0);
	int myLandConstraint            = rmCreateTerrainDistanceConstraint("land constraint","land",false,1.0);

// Areas

	rmSetStatusText("",0.07);

	int myIsland = rmCreateArea("island");
	rmSetAreaBaseHeight(myIsland,1);
	rmSetAreaCoherence(myIsland,0.5);
	rmSetAreaHeightBlend(myIsland,10);
	rmSetAreaLocation(myIsland,0.5,0.5);
	rmSetAreaSize(myIsland,0.4,0.5);
	rmSetAreaSmoothDistance(myIsland,10);
	if(myEnvironment == 1) {
		rmSetAreaTerrainType(myIsland,"SnowA");
	}
	else {
		rmSetAreaTerrainType(myIsland,"SandC");
	}
	rmBuildArea(myIsland);

	rmSetStatusText("",0.10);

	int myCoast = rmCreateArea("coast",myIsland);
	if(myEnvironment == 1) {
		rmAddAreaTerrainLayer(myCoast,"SnowGrass25",0,2);
	}
	else {
		rmAddAreaTerrainLayer(myCoast,"GrassDirt75",0,2);
		rmAddAreaTerrainLayer(myCoast,"GrassDirt50",2,4);
		rmAddAreaTerrainLayer(myCoast,"GrassDirt25",4,6);
	}
	rmSetAreaBaseHeight(myCoast,3);
	rmSetAreaCoherence(myCoast,0.3);
	rmSetAreaHeightBlend(myCoast,10);
	rmSetAreaLocation(myCoast,0.5,0.5);
	rmSetAreaSize(myCoast,0.2,0.3);
	if(myEnvironment == 1) {
		rmSetAreaTerrainType(myCoast,"SnowGrass50");
	}
	else {
		rmSetAreaTerrainType(myCoast,"GrassA");
	}
	rmBuildArea(myCoast);

	rmSetStatusText("",0.13);

	int myForest = rmCreateArea("forest",myIsland);
	rmSetAreaBaseHeight(myForest,5);
	rmSetAreaCoherence(myForest,1);
	rmSetAreaHeightBlend(myForest,10);
	if(myEnvironment == 1) {
		rmSetAreaForestType(myForest,"Snow Pine Forest");
	}
	else {
		rmSetAreaForestType(myForest,"Palm Forest");
	}
	rmSetAreaLocation(myForest,0.5,0.5);
	rmSetAreaSize(myForest,0.07,0.07);
	rmBuildArea(myForest);

	rmSetStatusText("",0.16);

	int myVolcano = rmCreateArea("volcano",myIsland);
	rmAddAreaRemoveType(myVolcano,"tree");
	rmSetAreaBaseHeight(myVolcano,25);
	rmSetAreaCoherence(myVolcano,1);
	rmSetAreaHeightBlend(myVolcano,3);
	rmSetAreaLocation(myVolcano,0.5,0.5);
	rmSetAreaSize(myVolcano,0.03,0.03);
	rmBuildArea(myVolcano);

	rmSetStatusText("",0.19);

	int myLava = rmCreateArea("lava",myVolcano);
	rmSetAreaBaseHeight(myLava,1);
	rmSetAreaCoherence(myLava,1);
	rmSetAreaHeightBlend(myLava,1);
	rmSetAreaLocation(myLava,0.5,0.5);
	rmSetAreaSize(myLava,0.01,0.01);
	rmBuildArea(myLava);

	rmSetStatusText("",0.22);

	int myPaint = rmCreateArea("paint",myIsland);
	if(myEnvironment == 1) {
		rmAddAreaTerrainLayer(myPaint,"NorseRoadA",0,5);
		rmAddAreaTerrainLayer(myPaint,"SnowGrass50",5,rmZFractionToMeters(0.065));
		rmAddAreaTerrainLayer(myPaint,"CliffNorseA",rmZFractionToMeters(0.065),rmZFractionToMeters(0.08));
		rmAddAreaTerrainLayer(myPaint,"CliffGreekA",rmZFractionToMeters(0.08),rmZFractionToMeters(0.0975));
	}
	else {
		rmAddAreaTerrainLayer(myPaint,"GreekRoadA",0,5);
		rmAddAreaTerrainLayer(myPaint,"GrassA",5,rmZFractionToMeters(0.065));
		rmAddAreaTerrainLayer(myPaint,"CliffGreekA",rmZFractionToMeters(0.065),rmZFractionToMeters(0.0975));
	}
	rmSetAreaCoherence(myPaint,1);
	rmSetAreaLocation(myPaint,0.5,0.5);
	rmSetAreaSize(myPaint,0.2,0.2);
	rmSetAreaTerrainType(myPaint,"Hades7");
	rmBuildArea(myPaint);

// Players

	rmSetStatusText("",0.25);

	rmPlacePlayersCircular(0.25,0.25,rmDegreesToRadians(5.0));

	float playerFraction = rmAreaTilesToFraction(3200);

	for(i = 1; < cNumberPlayers) {
		int myPlayer = rmCreateArea("Player"+i);
		rmSetAreaCoherence(myPlayer,1);
		rmSetAreaLocPlayer(myPlayer,i);
		rmSetAreaSize(myPlayer,0.9 * playerFraction * 2.5,1.1 * playerFraction * 2.5);
		rmSetPlayerArea(i,myPlayer);
		rmBuildArea(myPlayer);
	}

// ...

	rmSetStatusText("",0.28);
	rmSetStatusText("",0.31);
	rmSetStatusText("",0.34);
	rmSetStatusText("",0.37);

// Objects

	rmSetStatusText("",0.40);

	int myTownCenter = rmCreateObjectDef("town center");
	rmAddObjectDefConstraint(myTownCenter,myLandConstraint);
	rmAddObjectDefItem(myTownCenter,"Settlement Level 1",1,0.0);
	rmPlaceObjectDefPerPlayer(myTownCenter,true);

	rmSetStatusText("",0.43);

	for(i = 1; < cNumberPlayers) {
		int myFort = rmCreateObjectDef("Fort"+i);
		rmAddObjectDefConstraint(myFort,myAvoidSettlementConstraint);
		rmAddObjectDefConstraint(myFort,myAvoidTreeConstraint);
		rmAddObjectDefConstraint(myFort,myLandConstraint);
		if(rmGetPlayerCulture(i) == cCultureEgyptian) {
			rmAddObjectDefItem(myFort,"Migdol Stronghold",1,0.0);
		}
		if(rmGetPlayerCulture(i) == cCultureGreek) {
			rmAddObjectDefItem(myFort,"Fortress",1,0.0);
		}
		if(rmGetPlayerCulture(i) == cCultureNorse) {
			rmAddObjectDefItem(myFort,"Hill Fort",1,0.0);
		}
		rmSetObjectDefMaxDistance(myFort,25.0);
		rmSetObjectDefMinDistance(myFort,25.0);
		rmPlaceObjectDefAtAreaLoc(myFort,i,rmAreaID("player"+i));
	}

	rmSetStatusText("",0.46);

	int mySettlement = rmCreateObjectDef("settlement");
	rmAddObjectDefConstraint(mySettlement,myAvoidSettlementConstraint);
	rmAddObjectDefConstraint(mySettlement,myAvoidTreeConstraint);
	rmAddObjectDefConstraint(mySettlement,myLandConstraint);
	rmAddObjectDefItem(mySettlement,"Settlement",1,0.0);
	rmSetObjectDefMaxDistance(mySettlement,75);
	rmSetObjectDefMinDistance(mySettlement,50);
	rmPlaceObjectDefPerPlayer(mySettlement,false,2);

	rmSetStatusText("",0.49);

	int myRelic = rmCreateObjectDef("relic");
	rmAddObjectDefConstraint(myRelic,myAvoidRelicConstraint);
	rmAddObjectDefConstraint(myRelic,myAvoidSettlementConstraint);
	rmAddObjectDefConstraint(myRelic,myAvoidTreeConstraint);
	rmAddObjectDefConstraint(myRelic,myLandConstraint);
	rmAddObjectDefItem(myRelic,"Relic",1,0.0);
	rmSetObjectDefMaxDistance(myRelic,75);
	rmSetObjectDefMinDistance(myRelic,50);
	rmPlaceObjectDefPerPlayer(myRelic,false,2);

	rmSetStatusText("",0.52);

	int myCampfire = rmCreateObjectDef("campfire");
	rmAddObjectDefConstraint(myCampfire,myLandConstraint);
	rmAddObjectDefItem(myCampfire,"Campfire",1,0.0);
	rmSetObjectDefMaxDistance(myCampfire,12.0);
	rmSetObjectDefMinDistance(myCampfire,12.0);
	rmPlaceObjectDefPerPlayer(myCampfire,true);

	rmSetStatusText("",0.55);

	for(i = 1; <= 6) {
		int myGold = rmCreateObjectDef("gold"+i);
		rmAddObjectDefConstraint(myGold,myAvoidGoldConstraint);
		rmAddObjectDefConstraint(myGold,myAvoidSettlementConstraint);
		rmAddObjectDefConstraint(myGold,myAvoidTreeConstraint);
		rmAddObjectDefConstraint(myGold,myLandConstraint);
		j = i % 3;
		if(j == 0) {
			rmAddObjectDefItem(myGold,"Gold Mine",1,0.0);
		}
		if(j == 1) {
			rmAddObjectDefItem(myGold,"Gold Mine Small",1,0.0);
		}
		if(j == 2) {
			rmAddObjectDefItem(myGold,"Gold Mine Tiny",1,0.0);
		}
		rmSetObjectDefMaxDistance(myGold,(10 * i) + 10);
		rmSetObjectDefMinDistance(myGold,10 * i);
		rmPlaceObjectDefPerPlayer(myGold,false);
	}

	rmSetStatusText("",0.58);

	for(i = 1; <= 3) {
		int myBush = rmCreateObjectDef("bush"+i);
		rmAddObjectDefConstraint(myBush,myAvoidFoodConstraint);
		rmAddObjectDefConstraint(myBush,myAvoidSettlementConstraint);
		rmAddObjectDefConstraint(myBush,myAvoidTreeConstraint);
		rmAddObjectDefConstraint(myBush,myLandConstraint);
		rmAddObjectDefItem(myBush,"Berry Bush",4 + (i * 2),4.0);
		rmSetObjectDefMaxDistance(myBush,25 * i);
		rmSetObjectDefMinDistance(myBush,(25 * i) - 10);
		rmPlaceObjectDefPerPlayer(myBush,false);
	}

	rmSetStatusText("",0.61);

	for(i = 1; <= 25) {
		int myTrees = rmCreateObjectDef("trees"+i);
		rmAddObjectDefConstraint(myTrees,myAvoidSettlementConstraint);
		rmAddObjectDefConstraint(myTrees,myLandConstraint);
		if(myEnvironment == 1) {
			rmAddObjectDefItem(myTrees,"Pine Snow",i,i);
		}
		else {
			rmAddObjectDefItem(myTrees,"Palm",i,i);
		}
		rmSetObjectDefMaxDistance(myTrees,rmZFractionToMeters(0.5));
		rmSetObjectDefMinDistance(myTrees,25.0);
		rmPlaceObjectDefPerPlayer(myTrees,false,11 - i);
	}

	rmSetStatusText("",0.64);

	for(i = 1; <= 3) {
		int myHerd = rmCreateObjectDef("herd"+i);
		rmAddObjectDefConstraint(myHerd,myAvoidHerdableConstraint);
		rmAddObjectDefConstraint(myHerd,myAvoidSettlementConstraint);
		rmAddObjectDefConstraint(myHerd,myAvoidTreeConstraint);
		rmAddObjectDefConstraint(myHerd,myLandConstraint);
		if(myEnvironment == 1) {
			rmAddObjectDefItem(myHerd,"Goat",3 + i,10.0);
		}
		else {
			rmAddObjectDefItem(myHerd,"Pig",3 + i,10.0);
		}
		rmSetObjectDefMaxDistance(myHerd,25 * i);
		rmSetObjectDefMinDistance(myHerd,(25 * i) - 10);
		rmPlaceObjectDefPerPlayer(myHerd,false);
	}

	rmSetStatusText("",0.67);

	for(i = 1; <= 3) {
		int myHunt = rmCreateObjectDef("hunt"+i);
		rmAddObjectDefConstraint(myHunt,myAvoidHuntableConstraint);
		rmAddObjectDefConstraint(myHunt,myAvoidSettlementConstraint);
		rmAddObjectDefConstraint(myHunt,myAvoidTreeConstraint);
		rmAddObjectDefConstraint(myHunt,myLandConstraint);
		if(myEnvironment == 1) {
			rmAddObjectDefItem(myHunt,"Elk",3 + i,10.0);
		}
		else {
			rmAddObjectDefItem(myHunt,"Boar",3 + i,10.0);
		}
		rmSetObjectDefMaxDistance(myHunt,25 * i);
		rmSetObjectDefMinDistance(myHunt,(25 * i) - 10);
		rmPlaceObjectDefPerPlayer(myHunt,false);
	}

	rmSetStatusText("",0.70);

	for(i = 1; <= 3) {
		int myFish = rmCreateObjectDef("fish"+i);
		rmAddObjectDefConstraint(myFish,myAvoidFishConstraint);
		rmAddObjectDefConstraint(myFish,myAvoidLandConstraint);
		j = i % 3;
		if(j == 0) {
			rmAddObjectDefItem(myFish,"Fish - Mahi",3,25.0);
		}
		if(j == 1) {
			rmAddObjectDefItem(myFish,"Fish - Perch",3,25.0);
		}
		if(j == 2) {
			rmAddObjectDefItem(myFish,"Fish - Salmon",3,25.0);
		}
		rmSetObjectDefMaxDistance(myFish,rmZFractionToMeters(0.5));
		rmSetObjectDefMinDistance(myFish,0.0);
		rmPlaceObjectDefPerPlayer(myFish,false,5);
	}

	rmSetStatusText("",0.73);

	for(i = 1; <= 2) {
		int mySeaLife = rmCreateObjectDef("sealife"+i);
		rmAddObjectDefConstraint(mySeaLife,myAvoidEdgeConstraint);
		rmAddObjectDefConstraint(mySeaLife,myAvoidLandConstraint);
		rmAddObjectDefConstraint(mySeaLife,myAvoidOrcaConstraint);
		rmAddObjectDefConstraint(mySeaLife,myAvoidSharkConstraint);
		rmAddObjectDefConstraint(mySeaLife,myAvoidWhaleConstraint);
		if(myEnvironment == 1) {
			j = i % 2;
			if(j == 0) {
				rmAddObjectDefItem(mySeaLife,"Orca",1,0.0);
			}
			if(j == 1) {
				rmAddObjectDefItem(mySeaLife,"Whale",1,0.0);
			}
		}
		else {
			rmAddObjectDefItem(mySeaLife,"Shark",1,0.0);
		}
		rmSetObjectDefMaxDistance(mySeaLife,rmZFractionToMeters(0.5));
		rmSetObjectDefMinDistance(mySeaLife,0.0);
		rmPlaceObjectDefPerPlayer(mySeaLife,false,5);
	}

	rmSetStatusText("",0.76);

	int mySmoke = rmCreateObjectDef("smoke");
	rmAddObjectDefItem(mySmoke,"Smoke Giant",1,0.0);
	rmPlaceObjectDefInArea(mySmoke,0,myLava,rmRandInt(1,5));

	rmSetStatusText("",0.79);

	int myFire = rmCreateObjectDef("fire");
	rmAddObjectDefItem(myFire,"Fire Object Big",1,0.0);
	rmPlaceObjectDefInArea(myFire,0,myLava,rmRandInt(1,5));

// Triggers

	rmSetStatusText("",0.82);

	rmCreateTrigger("timer1");
	rmCreateTrigger("timer2");
	rmCreateTrigger("vision");
	rmCreateTrigger("erupt");
	rmCreateTrigger("warning");

	rmSetStatusText("",0.85);

	j = 0;

	for(i = 1; < cNumberPlayers) {
		if(rmGetPlayerCiv(i) == cCivIsis) {
			j++;
		}
	}

	rmSwitchToTrigger(rmTriggerID("timer1"));
	rmAddTriggerCondition("Timer");
	rmSetTriggerConditionParamInt("Param1",5);
	rmAddTriggerEffect("Send Chat");
	rmSetTriggerEffectParamInt("PlayerID",0);
	rmSetTriggerEffectParam("Message","");
	if(j == 0) {
		rmAddTriggerEffect("Send Chat");
		rmSetTriggerEffectParamInt("PlayerID",0);
		rmSetTriggerEffectParam("Message","You Are Trespassing On A Sacred Island!");
		rmAddTriggerEffect("Send Chat");
		rmSetTriggerEffectParamInt("PlayerID",0);
		rmSetTriggerEffectParam("Message","You Have Angered The Volcano Gods!");
		if(cNumberNonGaiaPlayers > 6) {
			rmAddTriggerEffect("Send Chat");
			rmSetTriggerEffectParamInt("PlayerID",0);
			rmSetTriggerEffectParam("Message","");
			rmAddTriggerEffect("Send Chat");
			rmSetTriggerEffectParamInt("PlayerID",0);
			rmSetTriggerEffectParam("Message","WARNING: Because there are so many players on this map, the volcano eruption may lag.");
		}
	}
	else {
		rmAddTriggerEffect("Send Chat");
		rmSetTriggerEffectParamInt("PlayerID",0);
		rmSetTriggerEffectParam("Message","NOTE: Because Isis can block god powers, there will be no volcano eruptions during this game.");
	}
	rmAddTriggerEffect("Send Chat");
	rmSetTriggerEffectParamInt("PlayerID",0);
	rmSetTriggerEffectParam("Message","");
	if(j == 0) {
		rmAddTriggerEffect("Fire Event");
		rmSetTriggerEffectParamInt("EventID",rmTriggerID("timer2"));
	}
	rmSetTriggerActive(true);
	rmSetTriggerLoop(false);

	rmSetStatusText("",0.88);

	j = sqrt(myTiles) / 2;
	k = mySize / j;

	rmSwitchToTrigger(rmTriggerID("timer2"));
	rmAddTriggerCondition("Timer");
	rmSetTriggerConditionParamInt("Param1",20);
	rmAddTriggerEffect("Grant God Power");
	rmSetTriggerEffectParamInt("PlayerID",0);
	rmSetTriggerEffectParam("PowerName","Earthquake");
	rmSetTriggerEffectParamInt("Count",(k * k));
	rmAddTriggerEffect("Grant God Power");
	rmSetTriggerEffectParamInt("PlayerID",0);
	rmSetTriggerEffectParam("PowerName","Meteor");
	rmSetTriggerEffectParamInt("Count",(k * k));
	rmAddTriggerEffect("Grant God Power");
	rmSetTriggerEffectParamInt("PlayerID",0);
	rmSetTriggerEffectParam("PowerName","Vision");
	rmSetTriggerEffectParamInt("Count",(k * k));
	rmAddTriggerEffect("Send Chat");
	rmSetTriggerEffectParamInt("PlayerID",0);
	rmSetTriggerEffectParam("Message","");
	rmAddTriggerEffect("Send Chat");
	rmSetTriggerEffectParamInt("PlayerID",0);
	rmSetTriggerEffectParam("Message","Leave Or Feel Wrath Of The Volcano Gods!");
	rmAddTriggerEffect("Send Chat");
	rmSetTriggerEffectParamInt("PlayerID",0);
	rmSetTriggerEffectParam("Message","");
	rmAddTriggerEffect("Counter:Add Timer");
	rmSetTriggerEffectParam("Name","countdown");
	rmSetTriggerEffectParamInt("Start",900);
	rmSetTriggerEffectParamInt("Stop",1);
	rmSetTriggerEffectParam("Msg","Time Left Until Eruption");
	rmSetTriggerEffectParamInt("Event",rmTriggerID("vision"));
	rmSetTriggerActive(false);
	rmSetTriggerLoop(false);

	rmSetStatusText("",0.91);

	rmSwitchToTrigger(rmTriggerID("vision"));
	for(x = 1; < k) {
		for(z = 1; < k) {
			rmAddTriggerEffect("Invoke God Power");
			rmSetTriggerEffectParamInt("PlayerID",0);
			rmSetTriggerEffectParam("PowerName","Vision");
			rmSetTriggerEffectParam("DstPoint1",(x * j)+",0,"+(z * j));
		}
	}
	rmAddTriggerEffect("Fire Event");
	rmSetTriggerEffectParamInt("EventID",rmTriggerID("erupt"));
	rmSetTriggerActive(false);
	rmSetTriggerLoop(false);

	rmSetStatusText("",0.94);

	rmSwitchToTrigger(rmTriggerID("erupt"));
	i = rmRandInt(1,2);
	for(x = 1; < k) {
		for(z = 1; < k) {
			i++;
			rmAddTriggerEffect("Invoke God Power");
			rmSetTriggerEffectParamInt("PlayerID",0);
			if(i % 2 == 0) {
				rmSetTriggerEffectParam("PowerName","Earthquake");
			}
			else {
				rmSetTriggerEffectParam("PowerName","Meteor");
			}
			rmSetTriggerEffectParam("DstPoint1",(x * j)+",0,"+(z * j));
		}
	}
	rmAddTriggerEffect("Fire Event");
	rmSetTriggerEffectParamInt("EventID",rmTriggerID("warning"));
	rmSetTriggerActive(false);
	rmSetTriggerLoop(false);

	rmSetStatusText("",0.97);

	rmSwitchToTrigger(rmTriggerID("warning"));
	rmAddTriggerEffect("Send Chat");
	rmSetTriggerEffectParamInt("PlayerID",0);
	rmSetTriggerEffectParam("Message","");
	rmAddTriggerEffect("Send Chat");
	rmSetTriggerEffectParamInt("PlayerID",0);
	rmSetTriggerEffectParam("Message","The Eruption Has Started!");
	rmAddTriggerEffect("Send Chat");
	rmSetTriggerEffectParamInt("PlayerID",0);
	rmSetTriggerEffectParam("Message","Balls Of Fire Shall Rain Down From The Sky!");
	rmAddTriggerEffect("Send Chat");
	rmSetTriggerEffectParamInt("PlayerID",0);
	rmSetTriggerEffectParam("Message","The Earth Shall Shake From Beneath Your Feet!");
	rmAddTriggerEffect("Send Chat");
	rmSetTriggerEffectParamInt("PlayerID",0);
	rmSetTriggerEffectParam("Message","You Shall Feel The Wrath Of The Volcano Gods!");
	rmAddTriggerEffect("Send Chat");
	rmSetTriggerEffectParamInt("PlayerID",0);
	rmSetTriggerEffectParam("Message","");
	rmAddTriggerEffect("Fire Event");
	rmSetTriggerEffectParamInt("EventID",rmTriggerID("timer2"));
	rmSetTriggerActive(false);
	rmSetTriggerLoop(false);

	rmSetStatusText("",1.00);

}